Crate kcr_rc_app_stacks

Crate kcr_rc_app_stacks 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the rc.app.stacks group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

rc.app.stacks/v1

  • RuntimeComponent
  • RuntimeOperation

rc.app.stacks/v1beta2

  • RuntimeComponent
  • RuntimeOperation

Modules

v1
v1beta2