pub struct RuntimeComponentAffinityPodAffinity {
pub preferred_during_scheduling_ignored_during_execution: Option<Vec<RuntimeComponentAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution>>,
pub required_during_scheduling_ignored_during_execution: Option<Vec<RuntimeComponentAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution>>,
}Expand description
Controls the nodes the pod are scheduled to run on, based on labels on the pods that are already running on the node.
Fields
preferred_during_scheduling_ignored_during_execution: Option<Vec<RuntimeComponentAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution>>The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding “weight” to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
required_during_scheduling_ignored_during_execution: Option<Vec<RuntimeComponentAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution>>If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.