pub struct RuntimeComponentAutoscalingMetricsObjectTarget {
pub average_utilization: Option<i32>,
pub average_value: Option<IntOrString>,
pub type: String,
pub value: Option<IntOrString>,
}Expand description
target specifies the target value for the given metric
Fields
average_utilization: Option<i32>averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. Currently only valid for Resource metric source type
average_value: Option<IntOrString>averageValue is the target value of the average of the metric across all relevant pods (as a quantity)
type: Stringtype represents whether the metric type is Utilization, Value, or AverageValue
value: Option<IntOrString>value is the target value of the metric (as a quantity).