pub struct RuntimeComponentInitContainersStartupProbeTcpSocket {
pub host: Option<String>,
pub port: IntOrString,
}Expand description
TCPSocket specifies a connection to a TCP port.
Fields
host: Option<String>Optional: Host name to connect to, defaults to the pod IP.
port: IntOrStringNumber or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.