pub struct RuntimeComponentMonitoringEndpointsBasicAuth {
pub password: Option<RuntimeComponentMonitoringEndpointsBasicAuthPassword>,
pub username: Option<RuntimeComponentMonitoringEndpointsBasicAuthUsername>,
}Expand description
basicAuth configures the Basic Authentication credentials to use when
scraping the target.
Cannot be set at the same time as authorization, or oauth2.
Fields
password: Option<RuntimeComponentMonitoringEndpointsBasicAuthPassword>password specifies a key of a Secret containing the password for
authentication.
username: Option<RuntimeComponentMonitoringEndpointsBasicAuthUsername>username specifies a key of a Secret containing the username for
authentication.