pub struct RuntimeComponentStatefulSetStorageVolumeClaimTemplate {
pub api_version: Option<String>,
pub kind: Option<String>,
pub metadata: Option<RuntimeComponentStatefulSetStorageVolumeClaimTemplateMetadata>,
pub spec: Option<RuntimeComponentStatefulSetStorageVolumeClaimTemplateSpec>,
pub status: Option<RuntimeComponentStatefulSetStorageVolumeClaimTemplateStatus>,
}Expand description
A YAML object that represents a volumeClaimTemplate component of a StatefulSet.
Fields
api_version: Option<String>APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
kind: Option<String>Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
metadata: Option<RuntimeComponentStatefulSetStorageVolumeClaimTemplateMetadata>Standard object’s metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
spec: Option<RuntimeComponentStatefulSetStorageVolumeClaimTemplateSpec>spec defines the desired characteristics of a volume requested by a pod author. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims
status: Option<RuntimeComponentStatefulSetStorageVolumeClaimTemplateStatus>status represents the current information/status of a persistent volume claim. Read-only. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims