pub struct RuntimeComponentMonitoringEndpointsOauth2ClientSecret {
pub key: String,
pub name: Option<String>,
pub optional: Option<bool>,
}Expand description
clientSecret specifies a key of a Secret containing the OAuth2
client’s secret.
Fields
key: StringThe key of the secret to select from. Must be a valid secret key.
name: Option<String>Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
optional: Option<bool>Specify whether the Secret or its key must be defined