RuntimeComponentMonitoringEndpointsTlsConfig

Struct RuntimeComponentMonitoringEndpointsTlsConfig 

pub struct RuntimeComponentMonitoringEndpointsTlsConfig {
    pub ca: Option<RuntimeComponentMonitoringEndpointsTlsConfigCa>,
    pub ca_file: Option<String>,
    pub cert: Option<RuntimeComponentMonitoringEndpointsTlsConfigCert>,
    pub cert_file: Option<String>,
    pub insecure_skip_verify: Option<bool>,
    pub key_file: Option<String>,
    pub key_secret: Option<RuntimeComponentMonitoringEndpointsTlsConfigKeySecret>,
    pub max_version: Option<RuntimeComponentMonitoringEndpointsTlsConfigMaxVersion>,
    pub min_version: Option<RuntimeComponentMonitoringEndpointsTlsConfigMinVersion>,
    pub server_name: Option<String>,
}
TLS configuration to use when scraping the target.

Fields

ca: Option<RuntimeComponentMonitoringEndpointsTlsConfigCa>

Certificate authority used when verifying server certificates.

ca_file: Option<String>

Path to the CA cert in the Prometheus container to use for the targets.

cert: Option<RuntimeComponentMonitoringEndpointsTlsConfigCert>

Client certificate to present when doing client-authentication.

cert_file: Option<String>

Path to the client cert file in the Prometheus container for the targets.

insecure_skip_verify: Option<bool>

Disable target certificate validation.

key_file: Option<String>

Path to the client key file in the Prometheus container for the targets.

key_secret: Option<RuntimeComponentMonitoringEndpointsTlsConfigKeySecret>

Secret containing the client key file for the targets.

max_version: Option<RuntimeComponentMonitoringEndpointsTlsConfigMaxVersion>

Maximum acceptable TLS version.

It requires Prometheus >= v2.41.0.

min_version: Option<RuntimeComponentMonitoringEndpointsTlsConfigMinVersion>

Minimum acceptable TLS version.

It requires Prometheus >= v2.35.0.

server_name: Option<String>

Used to verify the hostname for the targets.