pub struct RuntimeComponentVolumesAzureFile {
pub read_only: Option<bool>,
pub secret_name: String,
pub share_name: String,
}Expand description
azureFile represents an Azure File Service mount on the host and bind mount to the pod. Deprecated: AzureFile is deprecated. All operations for the in-tree azureFile type are redirected to the file.csi.azure.com CSI driver.
Fields
read_only: Option<bool>readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
secret_name: StringsecretName is the name of secret that contains Azure Storage Account Name and Key
shareName is the azure share Name