This crate contains kube-rs compatible bindings for Kubernetes custom resources for the rc.app.stacks group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
rc.app.stacks/v1
RuntimeComponentRuntimeOperation
rc.app.stacks/v1beta2
RuntimeComponentRuntimeOperation