pub struct RuntimeComponentMonitoringEndpointsOauth2ClientIdConfigMap {
pub key: String,
pub name: Option<String>,
pub optional: Option<bool>,
}Expand description
ConfigMap containing data to use for the targets.
Fields
key: StringThe key to select.
name: Option<String>Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
optional: Option<bool>Specify whether the ConfigMap or its key must be defined